import CoreMotion
import SQLite3

class ActivityManager {
    let motionActivityManager = CMMotionActivityManager()

    func queryActivityStarting(
        from start: Date,
        to end: Date,
        to queue: OperationQueue,
        withHandler handler: @escaping CMMotionActivityQueryHandler
    ) {
        motionActivityManager.queryActivityStarting(from: start, to: end, to: queue, withHandler: handler)
    }


    func queryActivityData(from startDate: Date, to endDate: Date = Date()) {
            let operationQueue = OperationQueue()
            operationQueue.maxConcurrentOperationCount = 1 // Ensure only one operation is executed at a time

            queryActivityStarting(from: startDate, to: endDate, to: operationQueue) { [self] activities, error in
                if let error = error {
                    print("ActivityManager Error querying activity data: \(error.localizedDescription)")
                    return
                }

                guard let activities = activities else {
                    print("ActivityManager No activity data available")
                    return
                }

                for activity in activities {
                    let actData = ActivityData(from: activity)
                    print("ActivityManager raw activity data: \(activity)")
                    print("ActivityManager activity type: \(actData.type), confidence: \(actData.confidence), startDate: \(actData.startDate)")
                    DatabaseManager.shared.insertActivityData(type: actData.type, confidence: actData.confidence,
                    startDate:actData.startDate)
                }

            }
    }
}